.. moldrug documentation master file, created by
   sphinx-quickstart on Sun Jul 10 13:47:23 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to moldrug's documentation!
===================================
.. include:: ../README.rst
   
.. toctree::
   :caption: User guide
   :maxdepth: 2

   source/installation
   source/citations

.. toctree::
   :caption: Tutorials
   :maxdepth: 2
   :numbered:

   notebooks/quickstart
   notebooks/how_to

.. toctree::
   :caption: Documentation
   :maxdepth: 2
   :glob:

   source/api
   source/modules/*

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
